@@ -1,5 +1,5 @@
 """
-CommitDB Python Driver
+CommitDB Python Client
 
 A Python client for connecting to CommitDB SQL Server.
 
